==> search-ui-elasticsearch-connector-1.10.1.tgz: package/lib/esm/handlers/autocomplete/results.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import Searchkit, { MultiMatchQuery } from "@searchkit/sdk";
import { fieldResponseMapper } from "../common";
import { getResultFields } from "../search/Configuration";
function buildConfiguration({ host, index, apiKey, queryFields, resultFields }) {
    const { hitFields, highlightFields } = getResultFields(resultFields);
    const searchkitConfiguration = {
        host: host,
        index: index,
        connectionOptions: {
            apiKey: apiKey
        },
        query: new MultiMatchQuery({
            fields: queryFields
        }),
        hits: {
            fields: hitFields,
            highlightedFields: highlightFields
        }
    };
    return searchkitConfiguration;
}
export default function handler(state, queryConfig, host, index, apiKey, queryFields) {
    return __awaiter(this, void 0, void 0, function* () {
        const searchkitConfiguration = buildConfiguration({
            host,
            index,
            apiKey,
            queryFields,
            resultFields: queryConfig.results.result_fields
        });
        const response = yield Searchkit(searchkitConfiguration)
            .query(state.searchTerm)
            .execute({
            facets: false,
            hits: {
                from: 0,
                size: queryConfig.results.resultsPerPage || 5
            }
        });
        return response.hits.items.map(fieldResponseMapper);
    });
}

==> search-ui-elasticsearch-connector-1.11.1.tgz: package/lib/esm/handlers/autocomplete/results.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import Searchkit, { MultiMatchQuery } from "@searchkit/sdk";
import { fieldResponseMapper } from "../common";
import { getResultFields, getQueryFields } from "../search/Configuration";
function buildConfiguration({ host, index, apiKey, searchFields, resultFields }) {
    const { hitFields, highlightFields } = getResultFields(resultFields);
    const queryFields = getQueryFields(searchFields);
    const searchkitConfiguration = {
        host: host,
        index: index,
        connectionOptions: {
            apiKey: apiKey
        },
        query: new MultiMatchQuery({
            fields: queryFields
        }),
        hits: {
            fields: hitFields,
            highlightedFields: highlightFields
        }
    };
    return searchkitConfiguration;
}
export default function handler(state, queryConfig, host, index, apiKey) {
    return __awaiter(this, void 0, void 0, function* () {
        const searchkitConfiguration = buildConfiguration({
            host,
            index,
            apiKey,
            searchFields: queryConfig.results.search_fields,
            resultFields: queryConfig.results.result_fields
        });
        const response = yield Searchkit(searchkitConfiguration)
            .query(state.searchTerm)
            .execute({
            facets: false,
            hits: {
                from: 0,
                size: queryConfig.results.resultsPerPage || 5
            }
        });
        return response.hits.items.map(fieldResponseMapper);
    });
}
